==> adguardhome-0.106.3.tar.xz: adguardhome-0.106.3/.github/ISSUE_TEMPLATE/Bug_report.md <==
---
name: Bug report
about: Create a bug report to help us improve AdGuard Home
---

Have a question or an idea? Please search it [on our forum](https://github.com/AdguardTeam/AdGuardHome/discussions) to make sure it was not yet asked. If you cannot find what you had in mind, please [submit it here](https://github.com/AdguardTeam/AdGuardHome/discussions/new).

### Prerequisites

Please answer the following questions for yourself before submitting an issue. **YOU MAY DELETE THE PREREQUISITES SECTION.**

- [ ] I am running the latest version
- [ ] I checked the documentation and found no answer
- [ ] I checked to make sure that this issue has not already been filed

### Issue Details

<!-- Please include all relevant details about the environment you experienced the bug in.  If possible, include the result of running `./AdGuardHome -v --version` from the installation directory. -->

* **Version of AdGuard Home server:**
  * <!-- (e.g. v0.123.4) -->
* **How did you install AdGuard Home:**
  * <!-- (e.g. Built from source, Snapcraft, Docker, Github releases, etc.) -->
* **How did you setup DNS configuration:**
  * <!-- (System/Router/IoT) -->
* **If it's a router or IoT, please write device model:**
  * <!-- (e.g. Raspberry Pi 3 Model B) -->
* **CPU architecture:**
  * <!-- (e.g. AMD64, MIPS, etc.) -->
* **Operating system and version:**
  * <!-- (e.g. Ubuntu 18.04.1) -->

### Expected Behavior
<!-- A clear and concise description of what you expected to happen. -->

### Actual Behavior
<!-- A clear and concise description of what actually happened. -->

### Screenshots
<!-- If applicable, add screenshots to help explain your problem. -->

<details><summary>Screenshot:</summary>

<!--- drag and drop, upload or paste your screenshot to this area-->

</details>

### Additional Information
<!-- Add any other context about the problem here. -->

==> adguardhome-0.107.2.tar.xz: adguardhome-0.107.2/.github/ISSUE_TEMPLATE/Bug_report.md <==
---
name: Bug report
about: Create a bug report to help us improve AdGuard Home
---

Have a question or an idea? Please search it [on our forum](https://github.com/AdguardTeam/AdGuardHome/discussions) to make sure it was not yet asked. If you cannot find what you had in mind, please [submit it here](https://github.com/AdguardTeam/AdGuardHome/discussions/new).

### Prerequisites

Please answer the following questions for yourself before submitting an issue. **YOU MAY DELETE THE PREREQUISITES SECTION.**

- [ ] I am running the latest version
- [ ] I checked the documentation and found no answer
- [ ] I checked to make sure that this issue has not already been filed

### Issue Details

<!-- Please include all relevant details about the environment you experienced the bug in.  If possible, include the result of running `./AdGuardHome -v --version` from the installation directory. -->

* **Version of AdGuard Home server:**
  * <!-- (e.g. v0.123.4) -->
* **How did you install AdGuard Home:**
  * <!-- (e.g. Built from source, Snapcraft, Docker, GitHub releases, etc.) -->
* **How did you setup DNS configuration:**
  * <!-- (System/Router/IoT) -->
* **If it's a router or IoT, please write device model:**
  * <!-- (e.g. Raspberry Pi 3 Model B) -->
* **CPU architecture:**
  * <!-- (e.g. AMD64, MIPS, etc.) -->
* **Operating system and version:**
  * <!-- (e.g. Ubuntu 18.04.1) -->

### Expected Behavior
<!-- A clear and concise description of what you expected to happen. -->

### Actual Behavior
<!-- A clear and concise description of what actually happened. -->

### Screenshots
<!-- If applicable, add screenshots to help explain your problem. -->

<details><summary>Screenshot:</summary>

<!--- drag and drop, upload or paste your screenshot to this area-->

</details>

### Additional Information
<!-- Add any other context about the problem here. -->
